@@ -2,11 +2,11 @@
 #######################################################################
 """Product class for the Zope 3 based product package
 
-$Id: objectqueuehandler.py 49681 2008-01-23 14:17:03Z cray $
+$Id: objectqueuehandler.py 49723 2008-01-24 23:28:18Z cray $
 """
 __author__  = "Yegor Shershnev, 2008"
 __license__ = "GPL"
-__version__ = "$Revision: 49681 $"
+__version__ = "$Revision: 49723 $"
 
 from zope.interface import Interface
 from zope.interface import implements,implementedBy
@@ -14,20 +14,20 @@ from ng.app.objectqueue.interfaces import IObjectQueue
 
 def handleAdded(object, event) :
     try :
-        IObjectQueue(event.object).itemAdd(event.object)
+        IObjectQueue(object).itemAdd(object)
     except TypeError :
         pass
 
 def handleModified(object, event) :
     try :
-        IObjectQueue(object).itemModify(event.object)
+        IObjectQueue(object).itemModify(object)
     except TypeError :
         pass        
 
 
 def handleRemoved(object, event) :
     try :
-        IObjectQueue(object).itemRemove(event.object)
+        IObjectQueue(object).itemRemove(object)
     except TypeError :
         pass
                 
